#ifndef __MY_CONFIG_H
#define __MY_CONFIG_H
@TOP@

#undef DATADIR
#undef AUTOPILOT
#undef NETWORKING
#undef HAVE_GTK
#undef HAVE_QT

@BOTTOM@
#endif
